==> docx4j-openxml-objects-8.3.10-sources.jar: org/docx4j/com/microsoft/schemas/office/drawing/x2010/main/CTPhoto.java <==

package org.docx4j.com.microsoft.schemas.office.drawing.x2010.main;

import javax.xml.bind.Unmarshaller;
import javax.xml.bind.annotation.XmlAccessType;
import javax.xml.bind.annotation.XmlAccessorType;
import javax.xml.bind.annotation.XmlElement;
import javax.xml.bind.annotation.XmlTransient;
import javax.xml.bind.annotation.XmlType;
import org.jvnet.jaxb2_commons.ppp.Child;


/**
 * <p>Java class for CT_Photo complex type.
 * 
 * <p>The following schema fragment specifies the expected content contained within this class.
 * 
 * <pre>
 * &lt;complexType name="CT_Photo"&gt;
 *   &lt;complexContent&gt;
 *     &lt;restriction base="{http://www.w3.org/2001/XMLSchema}anyType"&gt;
 *       &lt;sequence&gt;
 *         &lt;element name="imgLayer" type="{http://schemas.microsoft.com/office/drawing/2010/main}CT_PictureLayer"/&gt;
 *       &lt;/sequence&gt;
 *     &lt;/restriction&gt;
 *   &lt;/complexContent&gt;
 * &lt;/complexType&gt;
 * </pre>
 * 
 * 
 */
@XmlAccessorType(XmlAccessType.FIELD)
@XmlType(name = "CT_Photo", propOrder = {
    "imgLayer"
})
public class CTPhoto implements Child
{

    @XmlElement(required = true)
    protected CTPictureLayer imgLayer;
    @XmlTransient
    private Object parent;

    /**
     * Gets the value of the imgLayer property.
     * 
     * @return
     *     possible object is
     *     {@link CTPictureLayer }
     *     
     */
    public CTPictureLayer getImgLayer() {
        return imgLayer;
    }

    /**
     * Sets the value of the imgLayer property.
     * 
     * @param value
     *     allowed object is
     *     {@link CTPictureLayer }
     *     
     */
    public void setImgLayer(CTPictureLayer value) {
        this.imgLayer = value;
    }

    /**
     * Gets the parent object in the object tree representing the unmarshalled xml document.
     * 
     * @return
     *     The parent object.
     */
    public Object getParent() {
        return this.parent;
    }

    public void setParent(Object parent) {
        this.parent = parent;
    }

    /**
     * This method is invoked by the JAXB implementation on each instance when unmarshalling completes.
     * 
     * @param parent
     *     The parent object in the object tree.
     * @param unmarshaller
     *     The unmarshaller that generated the instance.
     */
    public void afterUnmarshal(Unmarshaller unmarshaller, Object parent) {
        setParent(parent);
    }

}

==> docx4j-openxml-objects-11.5.2-sources.jar: org/docx4j/com/microsoft/schemas/office/drawing/x2010/main/CTPhoto.java <==

package org.docx4j.com.microsoft.schemas.office.drawing.x2010.main;

import jakarta.xml.bind.Unmarshaller;
import jakarta.xml.bind.annotation.XmlAccessType;
import jakarta.xml.bind.annotation.XmlAccessorType;
import jakarta.xml.bind.annotation.XmlElement;
import jakarta.xml.bind.annotation.XmlTransient;
import jakarta.xml.bind.annotation.XmlType;
import org.jvnet.jaxb2_commons.ppp.Child;


/**
 * <p>Java class for CT_Photo complex type.
 * 
 * <p>The following schema fragment specifies the expected content contained within this class.
 * 
 * <pre>
 * &lt;complexType name="CT_Photo"&gt;
 *   &lt;complexContent&gt;
 *     &lt;restriction base="{http://www.w3.org/2001/XMLSchema}anyType"&gt;
 *       &lt;sequence&gt;
 *         &lt;element name="imgLayer" type="{http://schemas.microsoft.com/office/drawing/2010/main}CT_PictureLayer"/&gt;
 *       &lt;/sequence&gt;
 *     &lt;/restriction&gt;
 *   &lt;/complexContent&gt;
 * &lt;/complexType&gt;
 * </pre>
 * 
 * 
 */
@XmlAccessorType(XmlAccessType.FIELD)
@XmlType(name = "CT_Photo", propOrder = {
    "imgLayer"
})
public class CTPhoto implements Child
{

    @XmlElement(required = true)
    protected CTPictureLayer imgLayer;
    @XmlTransient
    private Object parent;

    /**
     * Gets the value of the imgLayer property.
     * 
     * @return
     *     possible object is
     *     {@link CTPictureLayer }
     *     
     */
    public CTPictureLayer getImgLayer() {
        return imgLayer;
    }

    /**
     * Sets the value of the imgLayer property.
     * 
     * @param value
     *     allowed object is
     *     {@link CTPictureLayer }
     *     
     */
    public void setImgLayer(CTPictureLayer value) {
        this.imgLayer = value;
    }

    /**
     * Gets the parent object in the object tree representing the unmarshalled xml document.
     * 
     * @return
     *     The parent object.
     */
    public Object getParent() {
        return this.parent;
    }

    public void setParent(Object parent) {
        this.parent = parent;
    }

    /**
     * This method is invoked by the JAXB implementation on each instance when unmarshalling completes.
     * 
     * @param parent
     *     The parent object in the object tree.
     * @param unmarshaller
     *     The unmarshaller that generated the instance.
     */
    public void afterUnmarshal(Unmarshaller unmarshaller, Object parent) {
        setParent(parent);
    }

}
